@@ -3,6 +3,7 @@
 
 #define GDK_ENABLE_BROKEN
 #include "gdk.h"
+#include "gdkalias.h"
 
 /* enumerations from "gdkcursor.h" */
 GType
@@ -97,7 +98,6 @@ gdk_cursor_type_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdkdnd.h" */
 GType
 gdk_drag_action_get_type (void)
@@ -117,7 +117,6 @@ gdk_drag_action_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_drag_protocol_get_type (void)
 {
@@ -138,7 +137,6 @@ gdk_drag_protocol_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdkevents.h" */
 GType
 gdk_filter_return_get_type (void)
@@ -155,7 +153,6 @@ gdk_filter_return_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_event_type_get_type (void)
 {
@@ -204,7 +201,6 @@ gdk_event_type_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_event_mask_get_type (void)
 {
@@ -239,7 +235,6 @@ gdk_event_mask_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_visibility_state_get_type (void)
 {
@@ -255,7 +250,6 @@ gdk_visibility_state_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_scroll_direction_get_type (void)
 {
@@ -272,7 +266,6 @@ gdk_scroll_direction_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_notify_type_get_type (void)
 {
@@ -291,7 +284,6 @@ gdk_notify_type_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_crossing_mode_get_type (void)
 {
@@ -307,7 +299,6 @@ gdk_crossing_mode_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_property_state_get_type (void)
 {
@@ -322,7 +313,6 @@ gdk_property_state_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_window_state_get_type (void)
 {
@@ -342,7 +332,6 @@ gdk_window_state_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_setting_action_get_type (void)
 {
@@ -358,7 +347,6 @@ gdk_setting_action_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_owner_change_get_type (void)
 {
@@ -375,7 +363,6 @@ gdk_owner_change_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdkfont.h" */
 GType
 gdk_font_type_get_type (void)
@@ -392,7 +379,6 @@ gdk_font_type_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdkgc.h" */
 GType
 gdk_cap_style_get_type (void)
@@ -410,7 +396,6 @@ gdk_cap_style_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_fill_get_type (void)
 {
@@ -427,7 +412,6 @@ gdk_fill_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_function_get_type (void)
 {
@@ -456,7 +440,6 @@ gdk_function_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_join_style_get_type (void)
 {
@@ -472,7 +455,6 @@ gdk_join_style_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_line_style_get_type (void)
 {
@@ -488,7 +470,6 @@ gdk_line_style_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_subwindow_mode_get_type (void)
 {
@@ -503,7 +484,6 @@ gdk_subwindow_mode_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_gc_values_mask_get_type (void)
 {
@@ -535,7 +515,6 @@ gdk_gc_values_mask_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdkimage.h" */
 GType
 gdk_image_type_get_type (void)
@@ -553,7 +532,6 @@ gdk_image_type_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdkinput.h" */
 GType
 gdk_extension_mode_get_type (void)
@@ -570,7 +548,6 @@ gdk_extension_mode_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_input_source_get_type (void)
 {
@@ -587,7 +564,6 @@ gdk_input_source_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_input_mode_get_type (void)
 {
@@ -603,7 +579,6 @@ gdk_input_mode_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_axis_use_get_type (void)
 {
@@ -625,7 +600,6 @@ gdk_axis_use_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdkproperty.h" */
 GType
 gdk_prop_mode_get_type (void)
@@ -643,7 +617,6 @@ gdk_prop_mode_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdkregion.h" */
 GType
 gdk_fill_rule_get_type (void)
@@ -659,7 +632,6 @@ gdk_fill_rule_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_overlap_type_get_type (void)
 {
@@ -676,7 +648,6 @@ gdk_overlap_type_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdkrgb.h" */
 GType
 gdk_rgb_dither_get_type (void)
@@ -694,7 +665,6 @@ gdk_rgb_dither_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdktypes.h" */
 GType
 gdk_byte_order_get_type (void)
@@ -710,7 +680,6 @@ gdk_byte_order_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_modifier_type_get_type (void)
 {
@@ -738,7 +707,6 @@ gdk_modifier_type_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_input_condition_get_type (void)
 {
@@ -754,7 +722,6 @@ gdk_input_condition_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_status_get_type (void)
 {
@@ -772,7 +739,6 @@ gdk_status_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_grab_status_get_type (void)
 {
@@ -791,7 +757,6 @@ gdk_grab_status_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdkvisual.h" */
 GType
 gdk_visual_type_get_type (void)
@@ -812,7 +777,6 @@ gdk_visual_type_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdkwindow.h" */
 GType
 gdk_window_class_get_type (void)
@@ -828,7 +792,6 @@ gdk_window_class_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_window_type_get_type (void)
 {
@@ -847,7 +810,6 @@ gdk_window_type_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_window_attributes_type_get_type (void)
 {
@@ -868,7 +830,6 @@ gdk_window_attributes_type_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_window_hints_get_type (void)
 {
@@ -890,7 +851,6 @@ gdk_window_hints_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_window_type_hint_get_type (void)
 {
@@ -911,7 +871,6 @@ gdk_window_type_hint_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_wm_decoration_get_type (void)
 {
@@ -931,7 +890,6 @@ gdk_wm_decoration_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_wm_function_get_type (void)
 {
@@ -950,7 +908,6 @@ gdk_wm_function_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_gravity_get_type (void)
 {
@@ -973,7 +930,6 @@ gdk_gravity_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_window_edge_get_type (void)
 {
@@ -995,6 +951,8 @@ gdk_window_edge_get_type (void)
   return etype;
 }
 
+#define __GDK_ENUM_TYPES_C__
+#include "gdkaliasdef.c"
 
 /* Generated data ends here */
 
