@@ -64,10 +64,16 @@ struct _GdkGCX11
   GdkRegion *clip_region;
   guint16 dirty_mask;
   guint have_clip_mask : 1;
+  guint depth : 8;
+
+  GdkFill fill;
+  GdkBitmap *stipple;
+  GdkPixmap *tile;
 
   Picture fg_picture;
   XRenderColor fg_picture_color; 
   gulong fg_pixel;
+  gulong bg_pixel;
 };
 
 struct _GdkGCX11Class
@@ -102,7 +108,9 @@ gint _gdk_send_xevent      (GdkDisplay *display,
 
 GType _gdk_gc_x11_get_type (void);
 
-gboolean _gdk_x11_have_render         (GdkDisplay *display);
+gboolean _gdk_x11_have_render                 (GdkDisplay *display);
+gboolean _gdk_x11_have_render_with_trapezoids (GdkDisplay *display);
+
 Picture  _gdk_x11_gc_get_fg_picture   (GdkGC      *gc);
 void     _gdk_gc_x11_get_fg_xft_color (GdkGC      *gc,
 				       XftColor   *xftcolor);
@@ -175,6 +183,9 @@ void _gdk_dnd_init		(GdkDisplay *display);
 void _gdk_windowing_image_init  (GdkDisplay *display);
 void _gdk_input_init            (GdkDisplay *display);
 
+PangoRenderer *_gdk_x11_renderer_get (GdkDrawable *drawable,
+				      GdkGC       *gc);
+
 extern GdkDrawableClass  _gdk_x11_drawable_class;
 extern gboolean	         _gdk_use_xshm;
 extern const int         _gdk_nenvent_masks;
