@@ -29,13 +29,13 @@
 #include <X11/Xatom.h>
 #include <string.h>
 
-#include "gdkalias.h"
 #include "gdkx.h"
 #include "gdkproperty.h"
 #include "gdkselection.h"
 #include "gdkprivate.h"
 #include "gdkprivate-x11.h"
 #include "gdkdisplay-x11.h"
+#include "gdkalias.h"
 
 typedef struct _OwnerInfo OwnerInfo;
 
@@ -880,3 +880,6 @@ void gdk_free_compound_text (guchar *ctext)
   if (ctext)
     XFree (ctext);
 }
+
+#define __GDK_SELECTION_X11_C__
+#include "gdkaliasdef.c"
