@@ -32,8 +32,6 @@
 
 #include <gdk/gdkkeysyms.h>
 
-#include "gtkalias.h"
-
 #include "gtkaboutdialog.h"
 #include "gtkbutton.h"
 #include "gtkbbox.h"
@@ -51,6 +49,8 @@
 #include "gtkiconfactory.h"
 #include "gtkintl.h"
 
+#include "gtkalias.h"
+
 #include <string.h>
 
 typedef struct _GtkAboutDialogPrivate GtkAboutDialogPrivate;
@@ -489,6 +489,7 @@ gtk_about_dialog_init (GtkAboutDialog *about)
 
   /* Add the credits button */
   button = gtk_button_new_from_stock (_("_Credits"));
+  gtk_widget_set_no_show_all (button, TRUE);
   gtk_box_pack_end (GTK_BOX (GTK_DIALOG (about)->action_area), 
 		    button, FALSE, TRUE, 0); 
   gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (GTK_DIALOG (about)->action_area), button, TRUE);
@@ -498,6 +499,7 @@ gtk_about_dialog_init (GtkAboutDialog *about)
 
   /* Add the license button */
   button = gtk_button_new_from_stock (_("_License"));
+  gtk_widget_set_no_show_all (button, TRUE);
   gtk_box_pack_end (GTK_BOX (GTK_DIALOG (about)->action_area), 
 		    button, FALSE, TRUE, 0); 
   gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (GTK_DIALOG (about)->action_area), button, TRUE);
@@ -1147,7 +1149,7 @@ gtk_about_dialog_set_website_label (GtkAboutDialog *about,
     }
   g_free (tmp);
 
-  g_object_notify (G_OBJECT (about), "website_label");
+  g_object_notify (G_OBJECT (about), "website-label");
 }
 
 /**
@@ -1455,7 +1457,7 @@ gtk_about_dialog_set_logo (GtkAboutDialog *about,
   g_object_freeze_notify (G_OBJECT (about));
 
   if (gtk_image_get_storage_type (GTK_IMAGE (priv->logo_image)) == GTK_IMAGE_ICON_NAME)
-    g_object_notify (G_OBJECT (about), "logo_icon_name");
+    g_object_notify (G_OBJECT (about), "logo-icon-name");
 
   if (logo != NULL) 
     gtk_image_set_from_pixbuf (GTK_IMAGE (priv->logo_image), logo);
@@ -1537,7 +1539,7 @@ gtk_about_dialog_set_logo_icon_name (GtkAboutDialog *about,
 
   gtk_image_set_from_icon_name (GTK_IMAGE (priv->logo_image), icon_name,
 				GTK_ICON_SIZE_DIALOG);
-  g_object_notify (G_OBJECT (about), "logo_icon_name");
+  g_object_notify (G_OBJECT (about), "logo-icon-name");
 
   g_object_thaw_notify (G_OBJECT (about));
 }
@@ -1830,8 +1832,8 @@ add_credits_page (GtkAboutDialog *about,
     }
 
   view = gtk_text_view_new ();
-  g_signal_connect (about, "style_set",
-		    G_CALLBACK (text_view_style_set), view);
+  g_signal_connect_object (about, "style_set",
+		           G_CALLBACK (text_view_style_set), view, 0);
   
   buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
   gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (view), FALSE);
@@ -2217,6 +2219,9 @@ gtk_show_about_dialog (GtkWindow   *parent,
 	global_about_dialog = dialog;
       
     }
-  
+
   gtk_window_present (GTK_WINDOW (dialog));
 }
+
+#define __GTK_ABOUT_DIALOG_C__
+#include "gtkaliasdef.c"
