@@ -18,11 +18,11 @@
  */
 
 #include <config.h>
-#include "gtkalias.h"
 #include "gtkcellrenderer.h"
 #include "gtkintl.h"
 #include "gtkmarshalers.h"
 #include "gtktreeprivate.h"
+#include "gtkalias.h"
 
 static void gtk_cell_renderer_init       (GtkCellRenderer      *cell);
 static void gtk_cell_renderer_class_init (GtkCellRendererClass *class);
@@ -117,6 +117,7 @@ gtk_cell_renderer_init (GtkCellRenderer *cell)
   cell->sensitive = TRUE;
   cell->is_expander = FALSE;
   cell->is_expanded = FALSE;
+  cell->editing = FALSE;
 }
 
 static void
@@ -454,7 +455,7 @@ gtk_cell_renderer_set_property (GObject      *object,
 	else
 	  g_warning ("Don't know color `%s'", g_value_get_string (value));
 
-	g_object_notify (object, "cell_background_gdk");
+	g_object_notify (object, "cell-background-gdk");
       }
       break;
     case PROP_CELL_BACKGROUND_GDK:
@@ -480,7 +481,7 @@ set_cell_bg_color (GtkCellRenderer *cell,
       if (!cell->cell_background_set)
         {
 	  cell->cell_background_set = TRUE;
-	  g_object_notify (G_OBJECT (cell), "cell_background_set");
+	  g_object_notify (G_OBJECT (cell), "cell-background-set");
 	}
 
       priv->cell_background.red = color->red;
@@ -492,7 +493,7 @@ set_cell_bg_color (GtkCellRenderer *cell,
       if (cell->cell_background_set)
         {
 	  cell->cell_background_set = FALSE;
-	  g_object_notify (G_OBJECT (cell), "cell_background_set");
+	  g_object_notify (G_OBJECT (cell), "cell-background-set");
 	}
     }
 }
@@ -687,7 +688,6 @@ gtk_cell_renderer_start_editing (GtkCellRenderer      *cell,
   if (GTK_CELL_RENDERER_GET_CLASS (cell)->start_editing == NULL)
     return NULL;
 
-  
   editable = GTK_CELL_RENDERER_GET_CLASS (cell)->start_editing (cell,
 								event,
 								widget,
@@ -700,6 +700,8 @@ gtk_cell_renderer_start_editing (GtkCellRenderer      *cell,
 		 cell_renderer_signals[EDITING_STARTED], 0,
 		 editable, path);
 
+  cell->editing = TRUE;
+
   return editable;
 }
 
@@ -770,11 +772,41 @@ gtk_cell_renderer_get_fixed_size (GtkCellRenderer *cell,
  * changes were not committed.
  *
  * Since: 2.4
+ * Deprecated: Use gtk_cell_renderer_stop_editing() instead
  **/
 void
 gtk_cell_renderer_editing_canceled (GtkCellRenderer *cell)
 {
   g_return_if_fail (GTK_IS_CELL_RENDERER (cell));
 
-  g_signal_emit (cell, cell_renderer_signals[EDITING_CANCELED], 0);
+  gtk_cell_renderer_stop_editing (cell, TRUE);
 }
+
+/**
+ * gtk_cell_renderer_stop_editing:
+ * @cell: A #GtkCellRenderer
+ * @canceled: %TRUE if the editing has been canceled
+ * 
+ * Informs the cell renderer that the editing is stopped.
+ * If @canceled is %TRUE, the cell renderer will emit the "editing-canceled" 
+ * signal. This function should be called by cell renderer implementations 
+ * in response to the "editing-done" signal of #GtkCellEditable.
+ *
+ * Since: 2.6
+ **/
+void
+gtk_cell_renderer_stop_editing (GtkCellRenderer *cell,
+				gboolean         canceled)
+{
+  g_return_if_fail (GTK_IS_CELL_RENDERER (cell));
+
+  if (cell->editing)
+    {
+      cell->editing = FALSE;
+      if (canceled)
+	g_signal_emit (cell, cell_renderer_signals[EDITING_CANCELED], 0);
+    }
+}
+
+#define __GTK_CELL_RENDERER_C__
+#include "gtkaliasdef.c"
