@@ -19,13 +19,13 @@
  */
 
 #include <config.h>
-#include "gtkalias.h"
 #include "gtkfilechooserdialog.h"
 #include "gtkfilechooserwidget.h"
 #include "gtkfilechooserutils.h"
 #include "gtkfilechooserembed.h"
 #include "gtkfilesystem.h"
 #include "gtktypebuiltins.h"
+#include "gtkalias.h"
 
 #include <stdarg.h>
 
@@ -60,6 +60,8 @@ static void     gtk_file_chooser_dialog_get_property (GObject               *obj
 						      GValue                *value,
 						      GParamSpec            *pspec);
 
+static void     gtk_file_chooser_dialog_map          (GtkWidget             *widget);
+static void     gtk_file_chooser_dialog_unmap        (GtkWidget             *widget);
 static void     gtk_file_chooser_dialog_style_set    (GtkWidget             *widget,
 						      GtkStyle              *previous_style);
 
@@ -118,6 +120,8 @@ gtk_file_chooser_dialog_class_init (GtkFileChooserDialogClass *class)
   gobject_class->get_property = gtk_file_chooser_dialog_get_property;
   gobject_class->finalize = gtk_file_chooser_dialog_finalize;
 
+  widget_class->map       = gtk_file_chooser_dialog_map;
+  widget_class->unmap     = gtk_file_chooser_dialog_unmap;
   widget_class->style_set = gtk_file_chooser_dialog_style_set;
 
   _gtk_file_chooser_install_properties (gobject_class);
@@ -397,8 +401,6 @@ gtk_file_chooser_dialog_constructor (GType                  type,
   _gtk_file_chooser_set_delegate (GTK_FILE_CHOOSER (object),
 				  GTK_FILE_CHOOSER (priv->widget));
 
-  _gtk_file_chooser_embed_initial_focus (GTK_FILE_CHOOSER_EMBED (priv->widget));
-
   gtk_widget_pop_composite_child ();
 
   return object;
@@ -487,6 +489,39 @@ set_default_size (GtkFileChooserDialog *dialog)
 }
 #endif
 
+/* GtkWidget::map handler */
+static void
+gtk_file_chooser_dialog_map (GtkWidget *widget)
+{
+  GtkFileChooserDialog *dialog = GTK_FILE_CHOOSER_DIALOG (widget);
+  GtkFileChooserDialogPrivate *priv = GTK_FILE_CHOOSER_DIALOG_GET_PRIVATE (dialog);
+
+  if (!GTK_WIDGET_MAPPED (priv->widget))
+    gtk_widget_map (priv->widget);
+
+  GTK_WIDGET_CLASS (parent_class)->map (widget);
+
+  _gtk_file_chooser_embed_initial_focus (GTK_FILE_CHOOSER_EMBED (priv->widget));
+}
+
+/* GtkWidget::unmap handler */
+static void
+gtk_file_chooser_dialog_unmap (GtkWidget *widget)
+{
+  GtkFileChooserDialog *dialog = GTK_FILE_CHOOSER_DIALOG (widget);
+  GtkFileChooserDialogPrivate *priv = GTK_FILE_CHOOSER_DIALOG_GET_PRIVATE (dialog);
+
+  GTK_WIDGET_CLASS (parent_class)->unmap (widget);
+
+  /* See bug #145470.  We unmap the GtkFileChooserWidget so that if the dialog
+   * is remapped, the widget will be remapped as well.  Implementations should
+   * refresh their contents when this happens, as some applications keep a
+   * single file chooser alive and map/unmap it as needed, rather than creating
+   * a new file chooser every time they need one.
+   */
+  gtk_widget_unmap (priv->widget);
+}
+
 static void
 gtk_file_chooser_dialog_style_set (GtkWidget *widget,
 				   GtkStyle  *previous_style)
@@ -599,8 +634,8 @@ gtk_file_chooser_dialog_new (const gchar         *title,
  * gtk_file_chooser_dialog_new_with_backend:
  * @title: Title of the dialog, or %NULL
  * @parent: Transient parent of the dialog, or %NULL
- * @backend: The name of the specific filesystem backend to use.
  * @action: Open or save mode for the dialog
+ * @backend: The name of the specific filesystem backend to use.
  * @first_button_text: stock ID or text to go in the first button, or %NULL
  * @Varargs: response ID for the first button, then additional (button, id) pairs, ending with %NULL
  *
@@ -632,3 +667,6 @@ gtk_file_chooser_dialog_new_with_backend (const gchar          *title,
 
   return result;
 }
+
+#define __GTK_FILE_CHOOSER_DIALOG_C__
+#include "gtkaliasdef.c"
