@@ -24,6 +24,7 @@
 #include "gtkfilechooser.h"
 #include "gtkfilesystem.h"
 #include "gtktypebuiltins.h"
+#include "gtkalias.h"
 
 static gboolean       delegate_set_current_folder     (GtkFileChooser    *chooser,
 						       const GtkFilePath *path,
@@ -145,13 +146,13 @@ _gtk_file_chooser_delegate_iface_init (GtkFileChooserIface *iface)
 
 /**
  * _gtk_file_chooser_set_delegate:
- * @receiver: a GOobject implementing #GtkFileChooser
- * @delegate: another GObject implementing #GtkFileChooser
+ * @receiver: a #GObject implementing #GtkFileChooser
+ * @delegate: another #GObject implementing #GtkFileChooser
  *
  * Establishes that calls on @receiver for #GtkFileChooser
  * methods should be delegated to @delegate, and that
  * #GtkFileChooser signals emitted on @delegate should be
- * forwarded to @receiver. Must be used in confunction with
+ * forwarded to @receiver. Must be used in conjunction with
  * _gtk_file_chooser_delegate_iface_init().
  **/
 void
@@ -162,7 +163,6 @@ _gtk_file_chooser_set_delegate (GtkFileChooser *receiver,
   g_return_if_fail (GTK_IS_FILE_CHOOSER (delegate));
 
   g_object_set_data (G_OBJECT (receiver), "gtk-file-chooser-delegate", delegate);
-
   g_signal_connect (delegate, "notify",
 		    G_CALLBACK (delegate_notify), receiver);
   g_signal_connect (delegate, "current-folder-changed",
@@ -175,10 +175,22 @@ _gtk_file_chooser_set_delegate (GtkFileChooser *receiver,
 		    G_CALLBACK (delegate_file_activated), receiver);
 }
 
+GQuark
+_gtk_file_chooser_delegate_get_quark (void)
+{
+  static GQuark quark = 0;
+
+  if (G_UNLIKELY (quark == 0))
+    quark = g_quark_from_static_string ("gtk-file-chooser-delegate");
+  
+  return quark;
+}
+
 static GtkFileChooser *
 get_delegate (GtkFileChooser *receiver)
 {
-  return g_object_get_data (G_OBJECT (receiver), "gtk-file-chooser-delegate");
+  return g_object_get_qdata (G_OBJECT (receiver),
+			     GTK_FILE_CHOOSER_DELEGATE_QUARK);
 }
 
 static gboolean
@@ -294,11 +306,12 @@ delegate_notify (GObject    *object,
 		 GParamSpec *pspec,
 		 gpointer    data)
 {
-  if (pspec->param_id >= GTK_FILE_CHOOSER_PROP_FIRST &&
-      pspec->param_id <= GTK_FILE_CHOOSER_PROP_LAST)
-    {
-      g_object_notify (data, pspec->name);
-    }
+  gpointer iface;
+
+  iface = g_type_interface_peek (g_type_class_peek (G_OBJECT_TYPE (object)),
+				 gtk_file_chooser_get_type ());
+  if (g_object_interface_find_property (iface, pspec->name))
+    g_object_notify (data, pspec->name);
 }
 
 static void
@@ -328,3 +341,6 @@ delegate_file_activated (GtkFileChooser    *chooser,
 {
   g_signal_emit_by_name (data, "file-activated");
 }
+
+#define __GTK_FILE_CHOOSER_UTILS_C__
+#include "gtkaliasdef.c"
