@@ -25,9 +25,9 @@
  */
 
 #include <config.h>
-#include "gtkalias.h"
 #include "gtkfixed.h"
 #include "gtkintl.h"
+#include "gtkalias.h"
 
 enum {
   CHILD_PROP_0,
@@ -492,10 +492,13 @@ gtk_fixed_forall (GtkContainer *container,
  * @has_window: %TRUE if a separate window should be created
  * 
  * Sets whether a #GtkFixed widget is created with a separate
- * #GdkWindow for widget->window or not. (By default, it will be
+ * #GdkWindow for @widget->window or not. (By default, it will be
  * created with no separate #GdkWindow). This function must be called
  * while the #GtkFixed is not realized, for instance, immediately after the
  * window is created.
+ * 
+ * This function was added to provide an easy migration path for
+ * older applications which may expect #GtkFixed to have a separate window.
  **/
 void
 gtk_fixed_set_has_window (GtkFixed *fixed,
@@ -529,3 +532,6 @@ gtk_fixed_get_has_window (GtkFixed *fixed)
 
   return !GTK_WIDGET_NO_WINDOW (fixed);
 }
+
+#define __GTK_FIXED_C__
+#include "gtkaliasdef.c"
