@@ -24,8 +24,11 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
+#include <config.h>
+
 #include "gtkmenu.h"
 #include "gtktearoffmenuitem.h"
+#include "gtkalias.h"
 
 #define ARROW_SIZE 10
 #define TEAR_LENGTH 5
@@ -38,8 +41,8 @@ static void gtk_tearoff_menu_item_size_request (GtkWidget             *widget,
 static gint gtk_tearoff_menu_item_expose     (GtkWidget             *widget,
 					      GdkEventExpose        *event);
 static void gtk_tearoff_menu_item_activate   (GtkMenuItem           *menu_item);
-static gint gtk_tearoff_menu_item_delete_cb  (GtkMenuItem           *menu_item,
-					      GdkEventAny           *event);
+static void gtk_tearoff_menu_item_parent_set (GtkWidget             *widget,
+					      GtkWidget             *previous);
 
 GType
 gtk_tearoff_menu_item_get_type (void)
@@ -88,6 +91,7 @@ gtk_tearoff_menu_item_class_init (GtkTearoffMenuItemClass *klass)
 
   widget_class->expose_event = gtk_tearoff_menu_item_expose;
   widget_class->size_request = gtk_tearoff_menu_item_size_request;
+  widget_class->parent_set = gtk_tearoff_menu_item_parent_set;
 
   menu_item_class->activate = gtk_tearoff_menu_item_activate;
 }
@@ -103,7 +107,7 @@ gtk_tearoff_menu_item_size_request (GtkWidget      *widget,
 				    GtkRequisition *requisition)
 {
   GtkTearoffMenuItem *tearoff;
-
+  
   tearoff = GTK_TEAROFF_MENU_ITEM (widget);
   
   requisition->width = (GTK_CONTAINER (widget)->border_width +
@@ -112,7 +116,7 @@ gtk_tearoff_menu_item_size_request (GtkWidget      *widget,
   requisition->height = (GTK_CONTAINER (widget)->border_width +
 			 widget->style->ythickness) * 2;
 
-  if (tearoff->torn_off)
+  if (GTK_IS_MENU (widget->parent) && GTK_MENU (widget->parent)->torn_off)
     {
       requisition->height += ARROW_SIZE;
     }
@@ -165,7 +169,7 @@ gtk_tearoff_menu_item_paint (GtkWidget   *widget,
       else
 	gdk_window_clear_area (widget->window, area->x, area->y, area->width, area->height);
 
-      if (tearoff_item->torn_off)
+      if (GTK_IS_MENU (widget->parent) && GTK_MENU (widget->parent)->torn_off)
 	{
 	  gint arrow_x;
 
@@ -238,36 +242,49 @@ gtk_tearoff_menu_item_expose (GtkWidget      *widget,
   return FALSE;
 }
 
-static gint
-gtk_tearoff_menu_item_delete_cb (GtkMenuItem *menu_item, GdkEventAny *event)
-{
-  gtk_tearoff_menu_item_activate (menu_item);
-  return TRUE;
-}
-
 static void
 gtk_tearoff_menu_item_activate (GtkMenuItem *menu_item)
 {
-  GtkTearoffMenuItem *tearoff_menu_item = GTK_TEAROFF_MENU_ITEM (menu_item);
-
-  tearoff_menu_item->torn_off = !tearoff_menu_item->torn_off;
-  gtk_widget_queue_resize (GTK_WIDGET (menu_item));
-
   if (GTK_IS_MENU (GTK_WIDGET (menu_item)->parent))
     {
       GtkMenu *menu = GTK_MENU (GTK_WIDGET (menu_item)->parent);
-      gboolean need_connect;
       
-      	need_connect = (tearoff_menu_item->torn_off && !menu->tearoff_window);
-
-	gtk_menu_set_tearoff_state (GTK_MENU (GTK_WIDGET (menu_item)->parent),
-				    tearoff_menu_item->torn_off);
-
-	if (need_connect)
-	  g_signal_connect_swapped (menu->tearoff_window,
-				    "delete_event",
-				    G_CALLBACK (gtk_tearoff_menu_item_delete_cb),
-				    menu_item);
+      gtk_widget_queue_resize (GTK_WIDGET (menu_item));
+      gtk_menu_set_tearoff_state (GTK_MENU (GTK_WIDGET (menu_item)->parent),
+				  !menu->torn_off);
     }
 }
 
+static void
+tearoff_state_changed (GtkMenu            *menu,
+		       GParamSpec         *pspec,
+		       gpointer            data)
+{
+  GtkTearoffMenuItem *tearoff_menu_item = GTK_TEAROFF_MENU_ITEM (data);
+
+  tearoff_menu_item->torn_off = gtk_menu_get_tearoff_state (menu);
+}
+
+static void
+gtk_tearoff_menu_item_parent_set (GtkWidget *widget,
+				  GtkWidget *previous)
+{
+  GtkTearoffMenuItem *tearoff_menu_item = GTK_TEAROFF_MENU_ITEM (widget);
+  GtkMenu *menu = GTK_IS_MENU (widget->parent) ? GTK_MENU (widget->parent) : NULL;
+
+  if (previous)
+    g_signal_handlers_disconnect_by_func (previous, 
+					  tearoff_state_changed, 
+					  tearoff_menu_item);
+  
+  if (menu)
+    {
+      tearoff_menu_item->torn_off = gtk_menu_get_tearoff_state (menu);
+      g_signal_connect (menu, "notify::tearoff-state", 
+			G_CALLBACK (tearoff_state_changed), 
+			tearoff_menu_item);
+    }  
+}
+
+#define __GTK_TEAROFF_MENU_ITEM_C__
+#include "gtkaliasdef.c"
