@@ -30,6 +30,7 @@
 #include "gtkmarshalers.h"
 #include "gtktogglebutton.h"
 #include "gtkintl.h"
+#include "gtkalias.h"
 
 #define DEFAULT_LEFT_POS  4
 #define DEFAULT_TOP_POS   4
@@ -285,7 +286,7 @@ gtk_toggle_button_set_mode (GtkToggleButton *toggle_button,
       if (GTK_WIDGET_VISIBLE (toggle_button))
 	gtk_widget_queue_resize (GTK_WIDGET (toggle_button));
 
-      g_object_notify (G_OBJECT (toggle_button), "draw_indicator");
+      g_object_notify (G_OBJECT (toggle_button), "draw-indicator");
     }
 }
 
@@ -496,3 +497,6 @@ gtk_toggle_button_update_state (GtkButton *button)
   _gtk_button_set_depressed (button, depressed); 
   gtk_widget_set_state (GTK_WIDGET (toggle_button), new_state);
 }
+
+#define __GTK_TOGGLE_BUTTON_C__
+#include "gtkaliasdef.c"
