@@ -20,7 +20,6 @@
  */
 
 #include <config.h>
-#include "gtkalias.h"
 #include "gtktoggletoolbutton.h"
 #include "gtkcheckmenuitem.h"
 #include "gtklabel.h"
@@ -28,6 +27,7 @@
 #include "gtkstock.h"
 #include "gtkintl.h"
 #include "gtkradiotoolbutton.h"
+#include "gtkalias.h"
 
 #define MENU_ID "gtk-toggle-tool-button-menu-id"
 
@@ -218,7 +218,7 @@ menu_item_activated (GtkWidget           *menu_item,
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (_gtk_tool_button_get_button (tool_button)),
 				    toggle_tool_button->priv->active);
 
-      g_signal_emit (G_OBJECT (toggle_tool_button), toggle_signals[TOGGLED], 0);
+      g_signal_emit (toggle_tool_button, toggle_signals[TOGGLED], 0);
     }
 }
 
@@ -241,7 +241,7 @@ button_toggled (GtkWidget           *widget,
 					  toggle_tool_button->priv->active);
 	}
 
-      g_signal_emit (G_OBJECT (toggle_tool_button), toggle_signals[TOGGLED], 0);
+      g_signal_emit (toggle_tool_button, toggle_signals[TOGGLED], 0);
     }
 }
 
@@ -334,3 +334,6 @@ gtk_toggle_tool_button_get_active (GtkToggleToolButton *button)
 
   return button->priv->active;
 }
+
+#define __GTK_TOGGLE_TOOL_BUTTON_C__
+#include "gtkaliasdef.c"
